<?php
/**
 * DT Resource Include Master admin class.
 *
 * @since  1.0.0
 * @package dt_resource_include_master
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'DT_Res_Inc_Master_Admin' ) ) :

	class DT_Res_Inc_Master_Admin {
		const OPTIONS_ID = 'dt-res-inc-master';

		protected $admin_page_id;
		protected $menu_slug = 'dt-res-inc-master';

		public function setup_options_action() {
			register_setting( self::OPTIONS_ID, self::OPTIONS_ID, array( $this, 'validate_options' ) );
		}

		public function setup_admin_page_action() {
			$this->admin_page_id = add_management_page(
				__( 'DT Res Inc Master', 'dt-resource-include-master' ),
				__( 'DT Res Inc Master', 'dt-resource-include-master' ),
				'edit_theme_options',
				$this->menu_slug,
				array( $this, 'admin_page' )
			);
		}

		/**
		 * Assemble plugin interface.
		 */
		public function admin_page() {
			?>

			<div id="dt-res-inc-master" class="wrap">
				<h2><?php echo esc_html( get_admin_page_title() ); ?></h2>
				<form action="options.php" method="post">
					<?php settings_fields( self::OPTIONS_ID ); ?>
					<fieldset>
						<legend><?php _e( 'Code in header', 'dt-resource-include-master' ); ?></legend>
						<textarea id="dt-res-inc-master--header" name="<?php echo $this->get_setting_name( 'header_code' ) ?>" rows="15" cols="100"><?php echo esc_html( $this->get_option( 'header_code' ) ); ?></textarea>
					</fieldset>
                    <fieldset>
                        <legend><?php _e( 'Code after body', 'dt-resource-include-master' ); ?></legend>
                        <textarea id="dt-res-inc-master--after-body" name="<?php echo $this->get_setting_name( 'after_body_code' ) ?>" rows="15" cols="100"><?php echo esc_html( $this->get_option( 'after_body_code' ) ); ?></textarea>
                    </fieldset>
                    <fieldset>
                        <legend><?php _e( 'Code before content', 'dt-resource-include-master' ); ?></legend>
                        <textarea id="dt-res-inc-master--before-content" name="<?php echo $this->get_setting_name( 'before_content_code' ) ?>" rows="15" cols="100"><?php echo esc_html( $this->get_option( 'before_content_code' ) ); ?></textarea>
                    </fieldset>
                    <fieldset>
                        <legend><?php _e( 'Code after content', 'dt-resource-include-master' ); ?></legend>
                        <textarea id="dt-res-inc-master--after-content" name="<?php echo $this->get_setting_name( 'after_content_code' ) ?>" rows="15" cols="100"><?php echo esc_html( $this->get_option( 'after_content_code' ) ); ?></textarea>
                    </fieldset>
					<fieldset>
						<legend><?php _e( 'Code in footer', 'dt-resource-include-master' ); ?></legend>
						<textarea id="dt-res-inc-master--footer" name="<?php echo $this->get_setting_name( 'footer_code' ) ?>" rows="15" cols="100"><?php echo esc_html( $this->get_option( 'footer_code' ) ); ?></textarea>
					</fieldset>
					<input type="submit" class="button button-primary" value="<?php _e( 'Save', 'dt-resource-include-master' ); ?>" />
				</form>
			</div>

			<?php
		}

		public function validate_options( $input ) {
			if ( is_multisite() ) {
				update_site_option( self::OPTIONS_ID . '-network', $input );
			}
			return $input;
		}

		public function get_option( $name ) {
			if ( is_multisite() ) {
				$options = get_site_option( self::OPTIONS_ID . '-network' );
			} else {
				$options = get_option( self::OPTIONS_ID );
			}

			if ( isset( $options[ $name ] ) ) {
				return $options[ $name ];
			}
			return null;
		}

		protected function get_setting_name( $name ) {
			return self::OPTIONS_ID . "[$name]" ;
		}
	}

endif;
