<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * Dashboard. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @since             1.0.3
 * @package           dt_resource_include_master
 *
 * @wordpress-plugin
 * Plugin Name:       DT Resource Include Master
 * Description:       Include any code in the header or/and in the footer.
 * Version:           1.0.0
 * Author:            Dream-Theme
 * Author URI:        http://dream-theme.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       dt-resource-include-master
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'DT_Res_Inc_Master' ) ) :

	/**
	 * Base class.
	 */
	class DT_Res_Inc_Master {
		/**
		 * @var DT_Res_Inc_Master
		 */
		public static $instance;

		public $plugin_dir;
		protected $admin;
		protected $public;

		/**
		 * @return DT_Res_Inc_Master
		 */
		public static function get_instance() {
			if ( ! self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		public function __construct() {
			$this->load_dependencies();
			$this->lunch();
		}

		protected function load_dependencies() {
			if ( ! $this->plugin_dir ) {
				$this->plugin_dir = plugin_dir_path( __FILE__ );
			}

			require $this->plugin_dir . 'class-dt-res-inc-master-admin.php';
			require $this->plugin_dir . 'class-dt-res-inc-master-public.php';

			$this->admin = new DT_Res_Inc_Master_Admin();
			$this->public = new DT_Res_Inc_Master_Public( $this->admin );
		}

		protected function lunch() {
			if ( is_admin() ) {

				// Setup options.
				add_action( 'admin_init', array( $this->admin, 'setup_options_action' ) );

				// Create admin page.
				add_action( 'admin_menu', array( $this->admin, 'setup_admin_page_action' ) );

			}

			// Print code in header.
			add_action( 'wp_head', array( $this->public, 'print_header_code_action' ), 9999 );

			// Print code in footer.
			add_action( 'wp_footer', array( $this->public, 'print_footer_code_action' ), 9999 );

			// Print code after body
			add_action( 'presscore_body_top', array( $this->public, 'print_after_body_code_action' ), 1 );


			add_action( 'presscore_before_content', array( $this->public, 'print_presscore_before_content_action' ), 1 );

			add_action( 'presscore_after_content', array( $this->public, 'print_presscore_after_content_action' ), 1 );


		}
	}

	DT_Res_Inc_Master::get_instance();

endif;
